==> aws-cdk-scala_2.12-0.13.0-sources.jar: io/burkard/cdk/services/pinpoint/cfnCampaign/MessageConfigurationProperty.scala <==
package io.burkard.cdk.services.pinpoint.cfnCampaign

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object MessageConfigurationProperty {

  def apply(
    inAppMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignInAppMessageProperty] = None,
    gcmMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    smsMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignSmsMessageProperty] = None,
    emailMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignEmailMessageProperty] = None,
    apnsMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    admMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    defaultMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    baiduMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None
  ): software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageConfigurationProperty =
    (new software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageConfigurationProperty.Builder)
      .inAppMessage(inAppMessage.orNull)
      .gcmMessage(gcmMessage.orNull)
      .smsMessage(smsMessage.orNull)
      .emailMessage(emailMessage.orNull)
      .apnsMessage(apnsMessage.orNull)
      .admMessage(admMessage.orNull)
      .defaultMessage(defaultMessage.orNull)
      .baiduMessage(baiduMessage.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.21.0-sources.jar: io/burkard/cdk/services/pinpoint/cfnCampaign/MessageConfigurationProperty.scala <==
package io.burkard.cdk.services.pinpoint.cfnCampaign

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object MessageConfigurationProperty {

  def apply(
    inAppMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignInAppMessageProperty] = None,
    gcmMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    smsMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignSmsMessageProperty] = None,
    emailMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignEmailMessageProperty] = None,
    customMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignCustomMessageProperty] = None,
    apnsMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    admMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    defaultMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None,
    baiduMessage: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageProperty] = None
  ): software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageConfigurationProperty =
    (new software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageConfigurationProperty.Builder)
      .inAppMessage(inAppMessage.orNull)
      .gcmMessage(gcmMessage.orNull)
      .smsMessage(smsMessage.orNull)
      .emailMessage(emailMessage.orNull)
      .customMessage(customMessage.orNull)
      .apnsMessage(apnsMessage.orNull)
      .admMessage(admMessage.orNull)
      .defaultMessage(defaultMessage.orNull)
      .baiduMessage(baiduMessage.orNull)
      .build()
}
